==> haskell-quickcheck-instances-0.3.31-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-instances
version:              0.3.31
visibility:           public
id:                   quickcheck-instances-0.3.31-CG84PmkMcsWGqjzJmZYQ6s
key:                  quickcheck-instances-0.3.31-CG84PmkMcsWGqjzJmZYQ6s
license:              BSD-3-Clause
copyright:            Copyright 2012-2016 Antoine Latter, 2017-2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Antoine Latter <aslatter@gmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/qc-instances
synopsis:             Common quickcheck instances
description:
    QuickCheck instances.

    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.

    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.

category:             Testing
abi:                  a630772053b3420df340165b3a87411c
exposed:              True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.Array.Byte
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.DataFix
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Primitive
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup Test.QuickCheck.Instances.Solo
    Test.QuickCheck.Instances.Strict Test.QuickCheck.Instances.Tagged
    Test.QuickCheck.Instances.Text Test.QuickCheck.Instances.Text.Short
    Test.QuickCheck.Instances.These Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector Test.QuickCheck.Instances.Void

hidden-modules:       Test.QuickCheck.Instances.CustomPrelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.31
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.31
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.31
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-instances
hs-libraries:         HSquickcheck-instances-0.3.31-CG84PmkMcsWGqjzJmZYQ6s
depends:
    OneTuple-0.4.2-5DyQFzq8WA51jg2V77K4Uo
    QuickCheck-2.14.3-CUJERxKFpT5Wrs3HEJyvt array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-GKEaqjX3nXNEZmMRebSTRD
    containers-0.6.7 data-fix-0.3.4-FO20vmPdeJ5BzvBM5IbLNx
    hashable-1.4.4.0-2lvxXC6j7O5I2GR31C0SqX
    integer-logarithms-1.0.4-II759Sb7WEJJ5m6XzGF5nA
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9
    primitive-0.9.1.0-3qHntBOAe4Y4he61Fs3OAc
    scientific-0.3.8.0-Lr1UPzAneM96vFGoFLDTYK
    splitmix-0.1.1-IYSPRunLh7f8eFgPV4F3NJ
    strict-0.5-4M5O4U7hGB2CIOCmI2n6XA
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    text-short-0.1.6-61JSmlAoOQSLZ3xCmH2jrS
    these-1.2.1-A1iF20SJCyz2l4WDICkAUH
    time-compat-1.9.7-Gb00e1n4e6J1jlCmhMXVWj transformers-0.5.6.2
    unordered-containers-0.2.20-G9Xtyt8hv5K8HhfrH8JX1r
    uuid-types-1.0.6-LFBxWu336OTGmTeDNwty1J
    vector-0.13.2.0-K0fBmK5qd7y3388236ZS0A

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-instances-0.3.31-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-instances
version:              0.3.31
visibility:           public
id:                   quickcheck-instances-0.3.31-9BXKMvVP62TIm5o9upiQ83
key:                  quickcheck-instances-0.3.31-9BXKMvVP62TIm5o9upiQ83
license:              BSD-3-Clause
copyright:            Copyright 2012-2016 Antoine Latter, 2017-2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Antoine Latter <aslatter@gmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/qc-instances
synopsis:             Common quickcheck instances
description:
    QuickCheck instances.

    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.

    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.

category:             Testing
abi:                  a1b94a00bb294f49e3481ee2a8ea2ddf
exposed:              True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.Array.Byte
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.DataFix
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Primitive
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup Test.QuickCheck.Instances.Solo
    Test.QuickCheck.Instances.Strict Test.QuickCheck.Instances.Tagged
    Test.QuickCheck.Instances.Text Test.QuickCheck.Instances.Text.Short
    Test.QuickCheck.Instances.These Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector Test.QuickCheck.Instances.Void

hidden-modules:       Test.QuickCheck.Instances.CustomPrelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.31
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.31
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.31
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-instances
hs-libraries:         HSquickcheck-instances-0.3.31-9BXKMvVP62TIm5o9upiQ83
depends:
    OneTuple-0.4.2-IOFILawEOp4I9m5GnYdL6z
    QuickCheck-2.14.3-FFJcwBneLUJ2oV3g9w1Xpr array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-2YouMSaLNxs7c1NFczsg30 containers-0.6.7
    data-fix-0.3.4-DoxVg04MTMR5N5KzVAeKWt
    hashable-1.4.4.0-JAwDEKKc8W9F1rpJyxQvSV
    integer-logarithms-1.0.4-Ay6UiiHv1U95CSWqAPJWre
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9
    primitive-0.9.1.0-IzoEy6gcvXy7FAbkwCq547
    scientific-0.3.8.0-k6LdIU0woW2bQtCT0Qggw
    splitmix-0.1.1-GgvlaogFfyDBcF11tSVIzR
    strict-0.5-I5xWqhe2lRr3wLK7yzNXKk
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    text-short-0.1.6-CoWKncQOOXmGJIezc13ox7
    these-1.2.1-FeVajncDa8C70xsdAYAVXX
    time-compat-1.9.7-LvjEjpP4VyU8jIZRT2XMkM transformers-0.5.6.2
    unordered-containers-0.2.20-DYKQz3mFVMa577dCuDCcCN
    uuid-types-1.0.6-4mh475TZucWJ7Z8xRWsRFR
    vector-0.13.2.0-3L5WVhzxugr6CqloTYM0zf

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
